================
Activity
================

A simple consumer Django app for Activity Service.

.. contents::
    :local:
    :backlinks: none


Installation
============

1. Run ``pip install p1-activity``
2. Add ``'activity'`` to ``INSTALLED_APPS`` in settings.py
3. Run `python manage.py migrate` to create activity models



Webhook
===========


API Client
===========
